==> nextcloud-24.0.6.tar.bz2: nextcloud/apps/viewer/l10n/pt_BR.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Visualizador",
    "Simple file viewer with slideshow for media" : "Visualizador simples com apresentação de slides para mídia",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your Nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Mostre suas últimas fotos e vídeos de férias como nos filmes, mostre um vislumbre de seu último romance diretamente de seu Nextcloud, escolha o melhor GIF de sua coleção graças à visualização direta de seus arquivos favoritos e muito mais!",
    "Your browser does not support audio." : "Seu navegador não tem suporte a áudio.",
    "Error loading {name}" : "Erro ao carregar {name}",
    "Image saved" : "Imagem gravada",
    "Error saving image" : "Erro ao salvar imagem",
    "Unsaved changes" : "Alterações não salvas",
    "Drop changes" : "Cancelar mudanças",
    "Content of \"{fileName}\"" : "Conteúdo de \"{fileName}\"",
    "Your browser does not support videos." : "Seu navegador não suporta vídeos.",
    "Edit" : "Editar",
    "Open sidebar" : "Abrir barra lateral",
    "Download" : "Baixar",
    "Delete" : "Excluir",
    "There is no plugin available to display this file type" : "Não há plug-in disponível para exibir este tipo de arquivo",
    "View" : "Visualizar",
    "Name" : "Nome",
    "Save" : "Salvar",
    "Save as" : "Salvar como",
    "Back" : "Voltar",
    "Loading …" : "Carregando …",
    "Reset" : "Redefinir",
    "All changes will be lost." : "Todas as mudanças serão perdidas.",
    "Are you sure you want to continue?" : "Tem certeza que deseja continuar?",
    "Cancel" : "Cancelar",
    "Continue" : "Continuar",
    "Undo" : "Desfazer",
    "Redo" : "Refazer",
    "Show original image" : "Mostrar imagem original",
    "Zoom in" : "Ampliar",
    "Zoom out" : "Diminuir zoom",
    "Toggle zoom menu" : "Habilitar menu de zoom",
    "Adjust" : "Ajustar",
    "Fine-tune" : "Sintonia fina",
    "Filters" : "Filtros",
    "Watermark" : "Marca d'água",
    "Draw" : "Desenhar",
    "Resize" : "Redimensionar",
    "Invalid image." : "Imagem inválida.",
    "Error while uploading the image." : "Erro ao fazer upload da imagem.",
    "are not images" : "não são imagens",
    "is not an image" : "não é uma imagem",
    "to be uploaded" : "para enviar",
    "Crop" : "Cortar",
    "Original" : "Original",
    "Custom" : "Personalizar",
    "Square" : "Quadrado",
    "Landscape" : "Paisagem",
    "Portrait" : "Retrato",
    "Ellipse" : "Elipse",
    "Classic TV" : "TV Clássica",
    "CinemaScope" : "CinemaScope",
    "Arrow" : "Flecha",
    "Blur" : "Embaçar",
    "Brightness" : "Brilho",
    "Contrast" : "Contraste",
    "Un-flip X" : "Desvirar X",
    "Flip X" : "Inverter X",
    "Un-flip Y" : "Desvirar Y",
    "Flip Y" : "Inverter Y",
    "HSV" : "HSV",
    "Hue" : "Cor",
    "Saturation" : "Saturação",
    "Value" : "Valor",
    "Image" : "Imagem",
    "Importing …" : "Importing …",
    "+ Add image" : "+ Adicionar imagem",
    "Line" : "Linha",
    "Pen" : "Caneta",
    "Polygon" : "Polígono",
    "Sides" : "Lados",
    "Rectangle" : "Retângulo",
    "Corner Radius" : "Raio do canto",
    "Width in pixels" : "Comprimento em pixels",
    "Height in pixels" : "Altura em pixels",
    "Toggle ratio lock" : "Habilitar trava de razão",
    "Reset to original image size" : "Voltar ao tamanho original",
    "Rotate" : "Rotação",
    "Text" : "Texto",
    "Text spacing" : "Espaçamento do texto",
    "Text alignment" : "Alinhamento de texto",
    "Font family" : "Família da fonte",
    "Size" : "Tamanho",
    "Letter spacing" : "Espaçamento entre letras",
    "Line height" : "Altura da linha",
    "Warmth" : "Temperatura",
    "+ Add watermark" : "+ Adicionar marca d'água",
    "Choose watermark type" : "Escolha o tipo de marca d'água",
    "Upload watermark" : "Enviar marca d'água",
    "Add as text" : "Adicionar como texto",
    "Padding" : "Preenchimento",
    "Shadow" : "Sombra",
    "Horizontal" : "Horizontal",
    "Vertical" : "Vertical",
    "Opacity" : "Opacidade",
    "Position" : "Posição",
    "Stroke" : "Derrame",
    "Save image as" : "Salvar imagem como",
    "Extension" : "Extensão",
    "Name is required." : "O nome é obrigatório.",
    "Quality" : "Qualidade",
    "Saved image size (width x height)" : "Imagem salva (largura x altura)",
    "Note that the selected crop area is lower than the applied resize which might cause quality decrease" : "Observe que a área de corte selecionada é menor que o redimensionamento aplicado, o que pode causar diminuição da qualidade",
    "Actual size (100%)" : "Tamanho real (100%)",
    "Fit size" : "Encaixar tamanho",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Mostre suas fotos e vídeos das férias mais recentes como nos filmes. Mostre um vislumbre do seu mais recente romance diretamente a partir do nextcloud. Escolha o melhor GIF da sua coleção, graças à pré-visualização direta dos seus arquivos favoritos e muito mais!"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-29.0.16.tar.bz2: nextcloud/apps/viewer/l10n/pt_BR.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Visualizador",
    "Simple file viewer with slideshow for media" : "Visualizador simples com apresentação de slides para mídia",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your Nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Mostre suas últimas fotos e vídeos de férias como nos filmes, mostre um vislumbre de seu último romance diretamente de seu Nextcloud, escolha o melhor GIF de sua coleção graças à visualização direta de seus arquivos favoritos e muito mais!",
    "Your browser does not support audio." : "Seu navegador não tem suporte a áudio.",
    "Error loading {name}" : "Erro ao carregar {name}",
    "Image saved" : "Imagem salva",
    "Error saving image" : "Erro ao salvar imagem",
    "Unsaved changes" : "Alterações não salvas",
    "Drop changes" : "Cancelar alterações",
    "Play the live photo" : "Reproduza a foto ao vivo",
    "LIVE" : "AO VIVO",
    "Your browser does not support videos." : "Seu navegador não suporta vídeos.",
    "This file no longer exists" : "Esse arquivo não existe mais",
    "There is no plugin available to display this file type" : "Não há plug-in disponível para exibir este tipo de arquivo",
    "Edit" : "Editar",
    "Exit full screen" : "Sair da tela cheia",
    "Full screen" : "Tela cheia",
    "Open sidebar" : "Abrir barra lateral",
    "Download" : "Baixar",
    "Delete" : "Excluir",
    "View" : "Visualizar",
    "Name" : "Nome",
    "Save" : "Salvar",
    "Save as" : "Salvar como",
    "Back" : "Voltar",
    "Loading …" : "Carregando …",
    "Reset" : "Redefinir",
    "All changes will be lost." : "Todas as alterações serão perdidas.",
    "Are you sure you want to continue?" : "Tem certeza que deseja continuar?",
    "Cancel" : "Cancelar",
    "Apply" : "Aplicar",
    "Warning" : "Aviso",
    "Confirm" : "Confirmar",
    "Discard changes" : "Descartar alterações",
    "Undo" : "Desfazer",
    "Redo" : "Refazer",
    "Show original image" : "Mostrar imagem original",
    "Zoom in" : "Aumentar zoom",
    "Zoom out" : "Diminuir zoom",
    "Toggle zoom menu" : "Alternar o menu de zoom",
    "Adjust" : "Ajustar",
    "Fine-tune" : "Aperfeiçoar",
    "Filters" : "Filtros",
    "Watermark" : "Marca d'água",
    "Draw" : "Desenhar",
    "Resize" : "Redimensionar",
    "Image name" : "Nome da imagem",
    "Invalid image." : "Imagem inválida.",
    "Error while uploading the image." : "Erro ao fazer upload da imagem.",
    "are not images" : "não são imagens",
    "is not an image" : "não é uma imagem",
    "to be uploaded" : "para enviar",
    "Crop" : "Cortar",
    "Original" : "Original",
    "Custom" : "Personalizar",
    "Square" : "Quadrado",
    "Landscape" : "Paisagem",
    "Portrait" : "Retrato",
    "Ellipse" : "Elipse",
    "Classic TV" : "TV clássica",
    "CinemaScope" : "CinemaScope",
    "Arrow" : "Flecha",
    "Blur" : "Desfocar",
    "Brightness" : "Luminosidade",
    "Contrast" : "Contraste",
    "Un-flip X" : "Desvirar X",
    "Flip X" : "Inverter X",
    "Un-flip Y" : "Desvirar Y",
    "Flip Y" : "Inverter Y",
    "HSV" : "HSV",
    "Hue" : "Matiz",
    "Saturation" : "Saturação",
    "Value" : "Valor",
    "Image" : "Imagem",
    "Importing …" : "Importando …",
    "+ Add image" : "+ Adicionar imagem",
    "Upload image" : "Fazer upload da imagem",
    "From gallery" : "Da galeria",
    "Line" : "Linha",
    "Pen" : "Caneta",
    "Polygon" : "Polígono",
    "Sides" : "Lados",
    "Rectangle" : "Retângulo",
    "Corner Radius" : "Raio do canto",
    "Width in pixels" : "Comprimento em pixels",
    "Height in pixels" : "Altura em pixels",
    "Toggle ratio lock" : "Alternar a trava de proporção",
    "Reset to original image size" : "Voltar ao tamanho original",
    "Rotate" : "Rotação",
    "Text" : "Texto",
    "Text spacing" : "Espaçamento do texto",
    "Text alignment" : "Alinhamento de texto",
    "Font family" : "Família da fonte",
    "Size" : "Tamanho",
    "Letter spacing" : "Espaçamento entre letras",
    "Line height" : "Altura da linha",
    "Warmth" : "Temperatura",
    "+ Add watermark" : "+ Adicionar marca d'água",
    "+ Add text watermark" : "+ Adicionar marca d'água de texto",
    "Choose watermark type" : "Escolha o tipo de marca d'água",
    "Upload watermark" : "Enviar marca d'água",
    "Add as text" : "Adicionar como texto",
    "Padding" : "Preenchimento",
    "Paddings" : "Preenchimentos",
    "Shadow" : "Sombra",
    "Horizontal" : "Horizontal",
    "Vertical" : "Vertical",
    "Opacity" : "Opacidade",
    "Transparency" : "Transparência",
    "Position" : "Posição",
    "Stroke" : "Traço",
    "Save image as" : "Salvar imagem como",
    "Extension" : "Extensão",
    "Format" : "Formato",
    "Name is required." : "O nome é obrigatório.",
    "Quality" : "Qualidade",
    "Saved image size (width x height)" : "Imagem salva (largura x altura)",
    "Note that the selected crop area is lower than the applied resize which might cause quality decrease" : "Observe que a área de corte selecionada é menor que o redimensionamento aplicado, o que pode causar diminuição da qualidade",
    "Actual size (100%)" : "Tamanho real (100%)",
    "Fit size" : "Encaixar tamanho",
    "Select image to add …" : "Selecione uma imagem para adicionar ...",
    "Failed to load image." : "Falha no upload da imagem.",
    "Menu" : "Menu",
    "Width" : "Largura",
    "Height" : "Altura",
    "No preview available for this crop item" : "Nenhuma visualização disponível para este item de corte"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
